==> zio-aws-config_3-5.17.130.2-sources.jar: zio/aws/config/model/FieldInfo.scala <==
package zio.aws.config.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.config.model.primitives.FieldName
import scala.jdk.CollectionConverters.*
final case class FieldInfo(name: Option[FieldName] = None) {
  def buildAwsValue()
      : software.amazon.awssdk.services.config.model.FieldInfo = {
    import FieldInfo.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.config.model.FieldInfo
      .builder()
      .optionallyWith(
        name.map(value => FieldName.unwrap(value): java.lang.String)
      )(_.name)
      .build()
  }
  def asReadOnly: zio.aws.config.model.FieldInfo.ReadOnly =
    zio.aws.config.model.FieldInfo.wrap(buildAwsValue())
}
object FieldInfo {
  private lazy val zioAwsBuilderHelper
      : BuilderHelper[software.amazon.awssdk.services.config.model.FieldInfo] =
    BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.config.model.FieldInfo =
      zio.aws.config.model.FieldInfo(name.map(value => value))
    def name: Option[FieldName]
    def getName: ZIO[Any, AwsError, FieldName] =
      AwsError.unwrapOptionField("name", name)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.config.model.FieldInfo
  ) extends zio.aws.config.model.FieldInfo.ReadOnly {
    override val name: Option[FieldName] = scala
      .Option(impl.name())
      .map(value => zio.aws.config.model.primitives.FieldName(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.config.model.FieldInfo
  ): zio.aws.config.model.FieldInfo.ReadOnly = new Wrapper(impl)
}

==> zio-aws-config_3-5.17.195.1-sources.jar: zio/aws/config/model/FieldInfo.scala <==
package zio.aws.config.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.config.model.primitives.FieldName
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class FieldInfo(name: Optional[FieldName] = Optional.Absent) {
  def buildAwsValue()
      : software.amazon.awssdk.services.config.model.FieldInfo = {
    import FieldInfo.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.config.model.FieldInfo
      .builder()
      .optionallyWith(
        name.map(value => FieldName.unwrap(value): java.lang.String)
      )(_.name)
      .build()
  }
  def asReadOnly: zio.aws.config.model.FieldInfo.ReadOnly =
    zio.aws.config.model.FieldInfo.wrap(buildAwsValue())
}
object FieldInfo {
  private lazy val zioAwsBuilderHelper
      : BuilderHelper[software.amazon.awssdk.services.config.model.FieldInfo] =
    BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.config.model.FieldInfo =
      zio.aws.config.model.FieldInfo(name.map(value => value))
    def name: Optional[FieldName]
    def getName: ZIO[Any, AwsError, FieldName] =
      AwsError.unwrapOptionField("name", name)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.config.model.FieldInfo
  ) extends zio.aws.config.model.FieldInfo.ReadOnly {
    override val name: Optional[FieldName] = zio.aws.core.internal
      .optionalFromNullable(impl.name())
      .map(value => zio.aws.config.model.primitives.FieldName(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.config.model.FieldInfo
  ): zio.aws.config.model.FieldInfo.ReadOnly = new Wrapper(impl)
}
